@@ -5,9 +5,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-24'; # DATE
+our $DATE = '2022-09-11'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.044'; # VERSION
+our $VERSION = '0.045'; # VERSION
 
 sub meta {
     +{
@@ -57,7 +57,7 @@ Data::Sah::Value::perl::Perl::this_mod
 
 =head1 VERSION
 
-This document describes version 0.044 of Data::Sah::Value::perl::Perl::this_mod (from Perl distribution Sah-Schemas-Perl), released on 2022-07-24.
+This document describes version 0.045 of Data::Sah::Value::perl::Perl::this_mod (from Perl distribution Sah-Schemas-Perl), released on 2022-09-11.
 
 =head1 DESCRIPTION
 
@@ -88,9 +88,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
