@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-24'; # DATE
+our $DATE = '2022-09-11'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.044'; # VERSION
+our $VERSION = '0.045'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl distribution name, e.g. Foo-Bar',
@@ -20,14 +20,23 @@ our $schema = [str => {
 
     description => <<'_',
 
-For convenience (particularly in CLI with tab completion), you can input one of:
+This is a schema you can use when you want to accept a Perl distribution name,
+e.g. `WWW-Mechanize`. It offers basic checking of syntax as well as a couple of
+conveniences. First, it offers completion from list of locally installed Perl
+distribution. Second, it contains coercion rule so you can also input
+`Foo::Bar`, `Foo/Bar`, `Foo/Bar.pm`, or even 'Foo.Bar' and it will be normalized
+into `Foo-Bar`.
 
-    Foo::Bar
-    Foo/Bar
-    Foo/Bar.pm
-    Foo.Bar
+To see this schema in action on the CLI, you can try e.g. the `dist-has-deb`
+script from <pm:App::DistUtils> and activate its tab completion (see its manpage
+for more details). Then on the CLI try typing:
 
-and it will be coerced into Foo-Bar form.
+    % dist-has-deb WWW-<tab>
+    % dist-has-deb dzp/<tab>
+
+Note that this schema does not check that the Perl disribution exists on CPAN or
+is installed locally. To check that, use the `perl::distname::installed` schema.
+And there's also a `perl::distname::not_installed` schema.
 
 _
 }];
@@ -47,7 +56,7 @@ Sah::Schema::perl::distname - Perl distribution name, e.g. Foo-Bar
 
 =head1 VERSION
 
-This document describes version 0.044 of Sah::Schema::perl::distname (from Perl distribution Sah-Schemas-Perl), released on 2022-07-24.
+This document describes version 0.045 of Sah::Schema::perl::distname (from Perl distribution Sah-Schemas-Perl), released on 2022-09-11.
 
 =head1 SYNOPSIS
 
@@ -136,14 +145,23 @@ L<Perinci::CmdLine> (L<Perinci::CmdLine::Lite>) to create a CLI:
 
 =head1 DESCRIPTION
 
-For convenience (particularly in CLI with tab completion), you can input one of:
+This is a schema you can use when you want to accept a Perl distribution name,
+e.g. C<WWW-Mechanize>. It offers basic checking of syntax as well as a couple of
+conveniences. First, it offers completion from list of locally installed Perl
+distribution. Second, it contains coercion rule so you can also input
+C<Foo::Bar>, C<Foo/Bar>, C<Foo/Bar.pm>, or even 'Foo.Bar' and it will be normalized
+into C<Foo-Bar>.
 
- Foo::Bar
- Foo/Bar
- Foo/Bar.pm
- Foo.Bar
+To see this schema in action on the CLI, you can try e.g. the C<dist-has-deb>
+script from L<App::DistUtils> and activate its tab completion (see its manpage
+for more details). Then on the CLI try typing:
 
-and it will be coerced into Foo-Bar form.
+ % dist-has-deb WWW-<tab>
+ % dist-has-deb dzp/<tab>
+
+Note that this schema does not check that the Perl disribution exists on CPAN or
+is installed locally. To check that, use the C<perl::distname::installed> schema.
+And there's also a C<perl::distname::not_installed> schema.
 
 =head1 HOMEPAGE
 
@@ -170,9 +188,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
