@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-24'; # DATE
+our $DATE = '2022-09-11'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.044'; # VERSION
+our $VERSION = '0.045'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl distribution name with version number suffix, e.g. Foo-Bar@0.001',
@@ -60,7 +60,7 @@ Sah::Schema::perl::distname_with_ver - Perl distribution name with version numbe
 
 =head1 VERSION
 
-This document describes version 0.044 of Sah::Schema::perl::distname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2022-07-24.
+This document describes version 0.045 of Sah::Schema::perl::distname_with_ver (from Perl distribution Sah-Schemas-Perl), released on 2022-09-11.
 
 =head1 SYNOPSIS
 
@@ -98,11 +98,11 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "Foo::Bar\@0.5_001";
+ $data = "Foo-Bar\@1.0.0";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "";
+ $data = "Foo-Bar";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A[A-Za-z_][A-Za-z_0-9]*(-[A-Za-z_0-9]+)*\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\\z"
 
 Often a schema has coercion rule or default value, so after validation the
@@ -113,12 +113,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "Foo::Bar\@0.5_001";
- my $res = $validator->($data); # => ["","Foo-Bar\@0.5_001"]
+ $data = "Foo-Bar\@1.0.0";
+ my $res = $validator->($data); # => ["","Foo-Bar\@1.0.0"]
  
  # a sample invalid data
- $data = "";
- my $res = $validator->($data); # => ["Must match regex pattern \\A[A-Za-z_][A-Za-z_0-9]*(-[A-Za-z_0-9]+)*\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\\z",""]
+ $data = "Foo-Bar";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A[A-Za-z_][A-Za-z_0-9]*(-[A-Za-z_0-9]+)*\@[0-9][0-9A-Za-z]*(\\.[0-9A-Za-z_]+)*\\z","Foo-Bar"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -217,9 +217,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
