@@ -4,9 +4,9 @@ use strict;
 use warnings;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-24'; # DATE
+our $DATE = '2022-09-11'; # DATE
 our $DIST = 'Sah-Schemas-Perl'; # DIST
-our $VERSION = '0.044'; # VERSION
+our $VERSION = '0.045'; # VERSION
 
 our $schema = [str => {
     summary => 'Perl module prefix, e.g. Foo::Bar::',
@@ -64,7 +64,7 @@ Sah::Schema::perl::modprefix - Perl module prefix, e.g. Foo::Bar::
 
 =head1 VERSION
 
-This document describes version 0.044 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2022-07-24.
+This document describes version 0.045 of Sah::Schema::perl::modprefix (from Perl distribution Sah-Schemas-Perl), released on 2022-09-11.
 
 =head1 SYNOPSIS
 
@@ -108,7 +108,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "::Foo";
+ $data = "::";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A(?:[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*::)?\\z"
 
 Often a schema has coercion rule or default value, so after validation the
@@ -123,8 +123,8 @@ prefiltered) value:
  my $res = $validator->($data); # => ["","Foo::"]
  
  # a sample invalid data
- $data = "::Foo";
- my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*::)?\\z","::Foo"]
+ $data = "::";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A(?:[A-Za-z_][A-Za-z_0-9]*(::[A-Za-z_0-9]+)*::)?\\z","::"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -227,9 +227,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
